=== removed file 'olive/backend/fileops.py'
--- olive/backend/fileops.py	2006-09-05 01:08:34 +0000
+++ olive/backend/fileops.py	1970-01-01 00:00:00 +0000
@@ -1,135 +0,0 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
-# Some parts of the code are:
-# Copyright (C) 2005, 2006 by Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-import os
-
-from bzrlib.errors import (BzrError, NotBranchError, NotVersionedError, 
-                           PermissionDenied)
-
-
-class MultipleMoveError(BzrError):
-    """ Occurs when moving/renaming more than 2 files, but the last argument is not a directory
-    
-    May occur in:
-        fileops.move()
-    """
-
-
-class NoMatchingFiles(BzrError):
-    """ No files found which could match the criteria
-    
-    May occur in:
-        fileops.remove()
-    """
-
-
-def move(names_list):
-    """ Move or rename given files.
-    
-    :param file_list: if two elements, then rename the first to the second, if more elements then move all of them to the directory specified in the last element
-    """
-    from bzrlib.builtins import tree_files
-    
-    tree, rel_names = tree_files(names_list)
-        
-    if os.path.isdir(names_list[-1]):
-        # move into existing directory
-        for pair in tree.move(rel_names[:-1], rel_names[-1]):
-            pass
-    else:
-        if len(names_list) != 2:
-            raise MultipleMoveError
-        tree.rename_one(rel_names[0], rel_names[1])
-
-
-def remove(file_list, new=False):
-    """ Make selected files unversioned.
-    
-    :param file_list: list of files/directories to be removed
-    
-    :param new: if True, the 'added' files will be removed
-    """
-    import bzrlib
-    from bzrlib.builtins import tree_files
-    
-    tree, file_list = tree_files(file_list)
-    
-    if new:
-        from bzrlib.delta import compare_trees
-        if (bzrlib.version_info[0] == 0) and (bzrlib.version_info[1] < 9):
-            added = [compare_trees(tree.basis_tree(), tree,
-                                   specific_files=file_list).added]
-        else:
-            added = [tree.changes_from(tree.basis_tree(),
-                                       specific_files=file_list).added]
-        file_list = sorted([f[0] for f in added[0]], reverse=True)
-        if len(file_list) == 0:
-            raise NoMatchingFiles
-    
-    tree.remove(file_list)
-
-
-def status(filename):
-    """ Get the status of a file.
-    
-    :param filename: the full path to the file
-    
-    :return: renamed | added | removed | modified | unchanged | unknown
-    """
-    import bzrlib
-    from bzrlib.delta import compare_trees
-    from bzrlib.workingtree import WorkingTree
-    
-    try:
-        tree1 = WorkingTree.open_containing(filename)[0]
-    except NotBranchError:
-        return 'unknown'
-    
-    branch = tree1.branch
-    tree2 = tree1.branch.repository.revision_tree(branch.last_revision())
-    
-    # find the relative path to the given file (needed for proper delta)
-    wtpath = tree1.basedir
-    fullpath = filename
-    i = 0
-    wtsplit = wtpath.split('/')
-    fpsplit = fullpath.split('/')
-    fpcopy = fullpath.split('/')
-    for item in fpsplit:
-        if i is not len(wtsplit):
-            if item == wtsplit[i]:
-                del fpcopy[0]
-            i = i + 1
-    rel = '/'.join(fpcopy)
-    
-    delta = tree1.changes_from(tree2,
-                                   want_unchanged=True,
-                                   specific_files=[rel])
-    
-    if len(delta.renamed):
-        return 'renamed'
-    elif len(delta.added):
-        return 'added'
-    elif len(delta.removed):
-        return 'removed'
-    elif len(delta.modified):
-        return 'modified'
-    elif len(delta.unchanged):
-        return 'unchanged'
-    else:
-        return 'unknown'

=== modified file 'olive/frontend/gtk/__init__.py'
--- olive/frontend/gtk/__init__.py	2006-09-04 23:33:13 +0000
+++ olive/frontend/gtk/__init__.py	2006-09-05 01:37:16 +0000
@@ -165,8 +165,6 @@
         
     def _load_right(self):
         """ Load data into the right panel. (Filelist) """
-        import olive.backend.fileops as fileops
-        
         # set cursor to busy
         self.comm.set_busy(self.treeview_right)
         
@@ -196,7 +194,7 @@
             liststore.append([gtk.STOCK_DIRECTORY, item, ''])
         for item in files:
             try:
-                status = fileops.status(path + '/' + item)
+                status = check_status(path + '/' + item)
             except errors.PermissionDenied:
                 continue
             
@@ -398,8 +396,6 @@
     
     def refresh_right(self, path=None):
         """ Refresh the file list. """
-        import olive.backend.fileops as fileops
-        
         self.set_busy(self.treeview_right)
         
         if path is None:
@@ -436,7 +432,7 @@
             liststore.append([gtk.STOCK_DIRECTORY, item, ''])
         for item in files:
             try:
-                status = fileops.status(path + '/' + item)
+                status = check_status(path + '/' + item)
             except errors.PermissionDenied:
                 continue
             
@@ -633,3 +629,53 @@
     def remove_bookmark(self, path):
         """ Remove bookmark. """
         return self.config.remove_section(path)
+
+def check_status(filename):
+    """ Get the status of a file.
+    
+    :param filename: the full path to the file
+    
+    :return: renamed | added | removed | modified | unchanged | unknown
+    """
+    import bzrlib
+    from bzrlib.delta import compare_trees
+    from bzrlib.workingtree import WorkingTree
+    
+    try:
+        tree1 = WorkingTree.open_containing(filename)[0]
+    except NotBranchError:
+        return 'unknown'
+    
+    branch = tree1.branch
+    tree2 = tree1.branch.repository.revision_tree(branch.last_revision())
+    
+    # find the relative path to the given file (needed for proper delta)
+    wtpath = tree1.basedir
+    fullpath = filename
+    i = 0
+    wtsplit = wtpath.split('/')
+    fpsplit = fullpath.split('/')
+    fpcopy = fullpath.split('/')
+    for item in fpsplit:
+        if i is not len(wtsplit):
+            if item == wtsplit[i]:
+                del fpcopy[0]
+            i = i + 1
+    rel = '/'.join(fpcopy)
+    
+    delta = tree1.changes_from(tree2,
+                                   want_unchanged=True,
+                                   specific_files=[rel])
+    
+    if len(delta.renamed):
+        return 'renamed'
+    elif len(delta.added):
+        return 'added'
+    elif len(delta.removed):
+        return 'removed'
+    elif len(delta.modified):
+        return 'modified'
+    elif len(delta.unchanged):
+        return 'unchanged'
+    else:
+        return 'unknown'

=== modified file 'olive/frontend/gtk/add.py'
--- olive/frontend/gtk/add.py	2006-09-05 01:08:34 +0000
+++ olive/frontend/gtk/add.py	2006-09-05 01:37:16 +0000
@@ -29,7 +29,6 @@
 
 import bzrlib
 import bzrlib.errors as errors
-import olive.backend.fileops as fileops
 
 class OliveAdd:
     """ Display the Add file(s) dialog and perform the needed actions. """

=== modified file 'olive/frontend/gtk/menu.py'
--- olive/frontend/gtk/menu.py	2006-09-05 01:08:34 +0000
+++ olive/frontend/gtk/menu.py	2006-09-05 01:37:16 +0000
@@ -153,7 +153,9 @@
             return
         
         try:
-            fileops.remove([directory + '/' + filename])
+            wt, path = WorkingTree.open_containing(directory+'/'+filename)
+            wt.remove(path)
+
         except errors.NotBranchError:
             self.dialog.error_dialog(_('Directory is not a branch'),
                                      _('You can perform this action only in a branch.'))

=== modified file 'olive/frontend/gtk/mkdir.py'
--- olive/frontend/gtk/mkdir.py	2006-09-05 01:08:34 +0000
+++ olive/frontend/gtk/mkdir.py	2006-09-05 01:37:16 +0000
@@ -29,7 +29,6 @@
     sys.exit(1)
 
 import bzrlib.errors as errors
-import olive.backend.fileops as fileops
 
 class OliveMkdir:
     """ Display the Make directory dialog and perform the needed actions. """

=== modified file 'olive/frontend/gtk/move.py'
--- olive/frontend/gtk/move.py	2006-09-04 23:33:13 +0000
+++ olive/frontend/gtk/move.py	2006-09-05 01:37:16 +0000
@@ -29,7 +29,6 @@
     sys.exit(1)
 
 import bzrlib.errors as errors
-import olive.backend.fileops as fileops
 
 class OliveMove:
     """ Display the Move dialog and perform the needed actions. """
@@ -74,17 +73,18 @@
         
         # Move the file to a directory
         try:
-            fileops.move([source, destination])
+            wt1, path1 = WorkingTree.open_containing(source)
+            wt2, path2 = WorkingTree.open_containing(destination)
+            if wt1.base != wt2.base:
+                self.dialog.error_dialog(_('Not the same branch'),
+                                         _('The destination is not in the same branch.'))
+                return
+
+            wt1.move([source], destination)
         except errors.NotBranchError:
             self.dialog.error_dialog(_('File is not in a branch'),
                                      _('The selected file is not in a branch.'))
             return
-        except errors.NotSameBranchError:
-            self.dialog.error_dialog(_('Not the same branch'),
-                                     _('The destination is not in the same branch.'))
-            return
-        except:
-            raise
 
         self.close()
         self.comm.refresh_right()

=== modified file 'olive/frontend/gtk/remove.py'
--- olive/frontend/gtk/remove.py	2006-09-04 23:33:13 +0000
+++ olive/frontend/gtk/remove.py	2006-09-05 01:37:16 +0000
@@ -28,7 +28,6 @@
     sys.exit(1)
 
 import bzrlib.errors as errors
-import olive.backend.fileops as fileops
 
 class OliveRemove:
     """ Display the Remove file(s) dialog and perform the needed actions. """
@@ -73,7 +72,8 @@
                 return
             
             try:
-                fileops.remove([directory + '/' + filename])
+                wt, path = WorkingTree.open_containing(directory + '/' + filename)
+                wt.remove(path)
             except errors.NotBranchError:
                 self.dialog.error_dialog(_('Directory is not a branch'),
                                          _('You can perform this action only in a branch.'))
@@ -89,7 +89,8 @@
         elif radio_new.get_active():
             # Remove added files recursively
             try:
-                fileops.remove([directory], True)
+                wt, path = WorkingTree.open_containing(directory)
+                wt.remove(path)
             except errors.NotBranchError:
                 self.dialog.error_dialog(_('Directory is not a branch'),
                                          _('You can perform this action only in a branch.'))

=== modified file 'olive/frontend/gtk/rename.py'
--- olive/frontend/gtk/rename.py	2006-09-05 01:08:34 +0000
+++ olive/frontend/gtk/rename.py	2006-09-05 01:37:16 +0000
@@ -29,7 +29,6 @@
     sys.exit(1)
 
 import bzrlib.errors as errors
-import olive.backend.fileops as fileops
 
 class OliveRename:
     """ Display the Rename dialog and perform the needed actions. """
@@ -78,17 +77,18 @@
         
         # Rename the file
         try:
-            fileops.move([source, destination])
+            wt1, path1 = WorkingTree.open_containing(source)
+            wt2, path2 = WorkingTree.open_containing(source)
+
+            if wt1.base != wt2.base:
+                self.dialog.error_dialog(_('Not the same branch'),
+                                         _('The destination is not in the same branch.'))
+                return
+            wt1.rename_one(source, destination)
         except errors.NotBranchError:
             self.dialog.error_dialog(_('File is not in a branch'),
                                      _('The selected file is not in a branch.'))
             return
-        except errors.NotSameBranchError:
-            self.dialog.error_dialog(_('Not the same branch'),
-                                     _('The destination is not in the same branch.'))
-            return
-        except:
-            raise
 
         self.close()
         self.comm.refresh_right()

